@@ -109,7 +109,27 @@ class Selenium(Scraper):
     def on_get_attribute(self, element, prop):
         return element.get_attribute(prop)
 
-    def click(self, path, element=None, timeout=0):
+    def click_all(self, path: str, element: any=None, timeout=0) -> None:
+        elements = self.xPath(path=path, element=element, timeout=timeout)
+        if elements is not None:
+
+            try:
+                element.click()
+            except Exception as e:
+                try:
+                    self.driver.execute_script("arguments[0].click();", element)
+                except:
+                    try:
+                        actions = ActionChains(self.driver)
+                        actions.click(element).perform()
+                    except:
+                        return None
+
+            return element
+        else:
+            return None
+
+    def click(self, path: str, element: any=None, timeout=0):
         element = self.xPath(path=path, element=element, timeout=timeout)
 
         if element is not None:
