@@ -6,11 +6,20 @@ class Config:
         self.config = ConfigParser()
         # read config.ini file
         self.config.read(path)
+        pass
 
     def get(self, section: str, key: str, default: any=None):
         # get config value
         if section in self.config and key in self.config[section]:
-            return self.config[section][key]
+            response = self.config[section][key]
+
+            if response == 'True':
+                return True
+            elif response == 'False':
+                return False
+            else:
+                return response
+
         elif (section in self.config and key not in self.config[section]) or (section not in self.config):
             if default is not None:
                 return default
